mysql.exceptions.server.Frm_Unknown_Type

Package mysql :: Package exceptions :: Module server :: Class Frm_Unknown_Type |
[hide private]
[frames] | no frames]

# Class Frm_Unknown_Type

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Frm_Unknown_Type

File '%s' has unknown type '%s' in its header

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`